@@ -336,22 +336,19 @@ impl<M> Table<M> where M: ArelAble {
     }
 }
 
-// #[cfg(test)]
-// mod tests {
-//     use super::*;
-//     #[test]
-//     fn it_works() {
-//         #[derive(Clone, Debug)]
-//         struct User {}
-//         impl ArelAble for User {}
-//         impl User {
-//             fn new() -> Self {
-//                 Self {}
-//             }
-//         }
-//         assert_eq!(User::table_name(), "users");
-//
-//         let table = Table::new(User::new());
-//         assert_eq!(table.table_name(), "users");
-//     }
-// }
\ No newline at end of file
+// sqlx
+#[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+impl<M> Table<M> where M: ArelAble {
+    pub async fn fetch_one(&mut self) -> anyhow::Result<M> {
+        let sql = self.to_sql()?;
+        let db_state = crate::visitors::get_db_state()?;
+        let row = sqlx::query(&sql).fetch_one(db_state.pool()).await?;
+        Ok(M::new_from_db_row(row)?)
+    }
+    pub async fn fetch_all(&mut self) -> anyhow::Result<Vec<M>> {
+        let sql = self.to_sql()?;
+        let db_state = crate::visitors::get_db_state()?;
+        let rows = sqlx::query(&sql).fetch_all(db_state.pool()).await?;
+        rows.into_iter().map(|row| M::new_from_db_row(row)).collect()
+    }
+}
\ No newline at end of file
