@@ -22,6 +22,7 @@ pub trait ArelAble: Sized {
     fn table_name() -> String {
         Table::<Self>::table_name()
     }
+    fn table_column_names() -> Vec<&'static str>;
     fn table() -> Table<Self> {
         Table::<Self>::new()
     }
@@ -50,4 +51,8 @@ pub trait ArelAble: Sized {
         table.with_delete_manager().r#where(condition);
         table
     }
+    // sqlx
+    #[cfg(any(feature = "sqlite", feature = "mysql", feature = "postgres", feature = "mssql"))]
+    fn new_from_db_row(db_row: sqlx::any::AnyRow) -> anyhow::Result<Self>;
+    fn assign_from_persisted_row_record(&mut self) -> anyhow::Result<&mut Self>;
 }
\ No newline at end of file
